@@ -1,3 +1,5 @@
+__version__ = "0.3.4"
+
 from scrapingant_client.client import ScrapingAntClient
 from scrapingant_client.cookie import Cookie
 from scrapingant_client.errors import (
@@ -5,6 +7,7 @@ from scrapingant_client.errors import (
     ScrapingantInvalidTokenException,
     ScrapingantInvalidInputException,
     ScrapingantInternalException,
+    ScrapingantSiteNotReachableException,
 )
 from scrapingant_client.response import Response
 
@@ -15,5 +18,6 @@ __all__ = [
     'ScrapingantInvalidTokenException',
     'ScrapingantInvalidInputException',
     'ScrapingantInternalException',
+    'ScrapingantSiteNotReachableException',
     'Response',
 ]
